# ##########
# UserModel
# ##########
UserModel.selectAllByLimit = SELECT user_email, user_id, user_posts, user_regdate, username, deleted, user_karma, user_from, user_website, user_viewemail \
	FROM jforum_users ORDER BY user_id FOR ORDERBY_NUM() BETWEEN ? AND ?

UserModel.lastGeneratedUserId = SELECT jforum_users_seq.current_value FROM serial_base

UserModel.selectById = SELECT u.*, \
	(SELECT COUNT(1) FROM jforum_privmsgs jp \
	WHERE jp.privmsgs_to_userid = u.user_id \
	AND jp.privmsgs_type = 1) AS private_messages \
	FROM jforum_users u \
	WHERE u.user_id = ?

UserModel.selectAllByGroup = SELECT user_email, u.user_id, user_posts, user_regdate, username, deleted, user_karma, user_from, user_website, user_viewemail \
	FROM jforum_users u, jforum_user_groups ug \
	WHERE u.user_id = ug.user_id \
	AND ug.group_id = ? \
	ORDER BY u.user_id \
	FOR ORDERBY_NUM() BETWEEN ? AND ?
UserModel.lastUserRegistered = SELECT user_id, username FROM jforum_users ORDER BY user_regdate DESC FOR ORDERBY_NUM() = 1

# #############
# PostModel
# #############
PostModel.lastGeneratedPostId = SELECT jforum_posts_seq.current_value FROM serial_base

PostModel.selectAllByTopicByLimit = SELECT p.post_id, topic_id, forum_id, p.user_id, post_time, poster_ip, enable_bbcode, p."attach", \
	enable_html, enable_smilies, enable_sig, post_edit_time, post_edit_count, status, pt.post_subject, pt.post_text, username, p.need_moderate \
	FROM jforum_posts p, jforum_posts_text pt, jforum_users u \
	WHERE p.post_id = pt.post_id \
	AND topic_id = ? \
	AND p.user_id = u.user_id \
	AND p.need_moderate = 0 \
	ORDER BY post_time ASC \
	FOR ORDERBY_NUM() BETWEEN ? AND ?

PostModel.selectByUserByLimit = SELECT p.post_id, topic_id, forum_id, p.user_id, post_time, poster_ip, enable_bbcode, p."attach", \
	enable_html, enable_smilies, enable_sig, post_edit_time, post_edit_count, status, pt.post_subject, pt.post_text, username, p.need_moderate \
	FROM jforum_posts p, jforum_posts_text pt, jforum_users u \
	WHERE p.post_id = pt.post_id \
	AND p.user_id = u.user_id \
	AND p.user_id = ? \
	AND p.need_moderate = 0 \
	AND forum_id IN(:fids:) \
	ORDER BY post_time DESC \
	FOR ORDERBY_NUM() BETWEEN ? AND ?

# ##########
# PollModel
# ##########
PollModel.lastGeneratedPollId = SELECT jforum_vote_desc_seq.current_value FROM serial_base 
		
# #############
# ForumModel
# #############
ForumModel.lastGeneratedForumId = SELECT jforum_forums_seq.current_value FROM serial_base

# #############
# TopicModel
# #############
TopicModel.selectAllByForumByLimit = SELECT t.*, p.user_id AS last_user_id, p.post_time, 0 AS "attach" \
	FROM jforum_topics t, jforum_posts p \
	WHERE t.forum_id = ? \
	AND p.post_id = t.topic_last_post_id \
	AND p.need_moderate = 0 \
	ORDER BY t.topic_type DESC, t.topic_last_post_id DESC \
	FOR ORDERBY_NUM() BETWEEN ? AND ?

TopicModel.selectByUserByLimit = SELECT t.*, p.user_id AS last_user_id, p.post_time, 0 AS "attach" \
	FROM jforum_topics t, jforum_posts p \
	WHERE p.post_id = t.topic_last_post_id \
	AND t.user_id = ? \
	AND p.need_moderate = 0 \
	AND t.forum_id IN(:fids:) \
	ORDER BY t.topic_last_post_id DESC \
	FOR ORDERBY_NUM() BETWEEN ? AND ?
		
TopicModel.lastGeneratedTopicId = SELECT jforum_topics_seq.current_value FROM serial_base 

TopicModel.selectRecentTopicsByLimit = SELECT t.*, p.user_id AS last_user_id, p.post_time, 0 AS "attach" \
	FROM jforum_topics t, jforum_posts p \
	WHERE p.post_id = t.topic_last_post_id \
	AND p.need_moderate = 0 \
	ORDER BY topic_last_post_id DESC \
	FOR ORDERBY_NUM() BETWEEN 1 AND ?

# #####################
# PrivateMessagesModel
# #####################
PrivateMessagesModel.lastGeneratedPmId = SELECT jforum_privmsgs_seq.current_value FROM serial_base 

# ############
# SearchModel
# ############
SearchModel.insertTopicsIds = INSERT INTO jforum_search_results ( topic_id, session_id, search_time ) SELECT DISTINCT t.topic_id, ?, sys_timestamp FROM jforum_topics t, jforum_posts p \
	WHERE t.topic_id = p.topic_id \
	AND p.post_id IN (:posts:)
	
SearchModel.getPostsToIndex = SELECT p.post_id, pt.post_text, pt.post_subject \
	FROM jforum_posts p, jforum_posts_text pt \
	WHERE p.post_id = pt.post_id \
	AND p.post_id BETWEEN ? AND ? \
	AND ROWNUM BETWEEN ? AND ?

# #############
# SmiliesModel
# #############
SmiliesModel.lastGeneratedSmilieId = SELECT jforum_smilies_seq.current_value FROM serial_base 

# ##################
# PermissionControl
# ##################
PermissionControl.lastGeneratedRoleId = SELECT jforum_roles_seq.current_value FROM serial_base 

# ##############
# CategoryModel
# ##############
CategoryModel.lastGeneratedCategoryId = SELECT jforum_categories_seq.current_value FROM serial_base 

# ################
# AttachmentModel
# ################
AttachmentModel.lastGeneratedAttachmentId = SELECT jforum_attach_seq.current_value FROM serial_base 

# ##########
# UserModel
# ##########
UserModel.login = SELECT user_id FROM jforum_users WHERE lower(username) = lower(?) AND user_password = ?

# ###############
# BanlistModel
# ###############
BanlistModel.lastGeneratedBanlistId = SELECT jforum_banlist_seq.current_value FROM serial_base 

GroupModel.addNew = INSERT INTO jforum_groups (group_id, group_name, group_description, parent_id) VALUES (jforum_groups_seq.next_value, ?, ?, ?)
CategoryModel.addNew = INSERT INTO jforum_categories (categories_id, title, display_order, moderated) VALUES (jforum_categories_seq.next_value, ?, ?, ?)
RankingModel.addNew = INSERT INTO jforum_ranks ( rank_id, rank_title, rank_min, rank_special) VALUES (jforum_ranks_seq.next_value, ?, ?, ? )
ConfigModel.insert = INSERT INTO jforum_config (config_id, config_name, config_value) VALUES (jforum_config_seq.next_value, ?, ?)
UserModel.addNew = INSERT INTO jforum_users (user_id, username, user_password, user_email, user_regdate, user_lastvisit, user_actkey) VALUES (jforum_users_seq.next_value, ?, ?, ?, ?, sys_timestamp, ?)
UserModel.addNewWithId = INSERT INTO jforum_users (username, user_password, user_email, user_regdate, user_lastvisit, user_actkey, user_id) VALUES (?, ?, ?, ?, sys_timestamp, ?, ?)
PostModel.addNewPost = INSERT INTO jforum_posts (post_id, topic_id, forum_id, user_id, post_time, poster_ip, enable_bbcode, enable_html, enable_smilies, enable_sig, post_edit_time, need_moderate) \
	VALUES (jforum_posts_seq.next_value, ?, ?, ?, ?, ?, ?, ?, ?, ?, sys_timestamp, ?)
PollModel.addNewPoll = INSERT INTO jforum_vote_desc (vote_id, topic_id, vote_text, vote_length, vote_start) VALUES (jforum_vote_desc_seq.next_value, ?, ?, ?, sys_timestamp)
ForumModel.addNew = INSERT INTO jforum_forums (forum_id, categories_id, forum_name, forum_desc, forum_order, moderated) VALUES (jforum_forums_seq.next_value, ?, ?, ?, ?, ?)
TopicModel.addNew = INSERT INTO jforum_topics (topic_id, forum_id, topic_title, user_id, topic_time, topic_first_post_id, topic_last_post_id, topic_type, moderated) \
	VALUES (jforum_topics_seq.next_value, ?, ?, ?, ?, ?, ?, ?, ?)
SearchModel.insertWords = INSERT INTO jforum_search_words (word_id, word, word_hash) VALUES (jforum_search_words_seq.next_value, ?, ?)
PermissionControl.addGroupRole = INSERT INTO jforum_roles (role_id, group_id, name) VALUES (jforum_roles_seq.next_value, ?, ?)
SmiliesModel.addNew = INSERT INTO jforum_smilies ( smilie_id, code, url, disk_name) VALUES (jforum_smilies_seq.next_value, ?, ?, ?)
PrivateMessageModel.add = INSERT INTO jforum_privmsgs ( privmsgs_id, privmsgs_type, privmsgs_subject, privmsgs_from_userid, \
	privmsgs_to_userid, privmsgs_date, privmsgs_enable_bbcode, privmsgs_enable_html, privmsgs_enable_smilies, \
	privmsgs_attach_sig ) \
	VALUES ( jforum_privmsgs.next_value, ?, ?, ?, ?, ?, ?, ?, ?, ? )
KarmaModel.add = INSERT INTO jforum_karma (karma_id, post_id, post_user_id, from_user_id, points, topic_id, rate_date) VALUES (jforum_karma_seq.next_value, ?, ?, ?, ?, ?, ?)
BookmarkModel.add = INSERT INTO jforum_bookmarks (bookmark_id, user_id, relation_id, relation_type, public_visible, title, description) VALUES (jforum_bookmarks_seq.next_value, ?, ?, ?, ?, ?, ?)
AttachmentModel.addQuotaLimit = INSERT INTO jforum_quota_limit (quota_limit_id, quota_desc, quota_limit, quota_type) VALUES (jforum_quota_limit_seq.next_value, ?, ?, ?)
AttachmentModel.addExtensionGroup = INSERT INTO jforum_extension_groups (extension_group_id, name, allow, upload_icon, download_mode) VALUES (jforum_extension_groups_seq.next_value, ?, ?, ?, ?)
AttachmentModel.addExtension = INSERT INTO jforum_extensions (extension_id, extension_group_id, description, upload_icon, extension, allow) VALUES (jforum_extensions_seq.next_value, ?, ?, ?, ?, ?)
AttachmentModel.addAttachment = INSERT INTO jforum_attach (attach_id, post_id, privmsgs_id, user_id) VALUES (jforum_attach_seq.next_value, ?, ?, ?)
AttachmentModel.addAttachmentInfo = INSERT INTO jforum_attach_desc (attach_desc_id, attach_id, physical_filename, real_filename, description, \
	mimetype, filesize, upload_time, thumb, extension_id ) VALUES (jforum_attach_desc_seq.next_value, ?, ?, ?, ?, ?, ?, ?, ?, ?)
AttachmentModel.setGroupQuota = INSERT INTO jforum_attach_quota (attach_quota_id, group_id, quota_limit_id) VALUES (jforum_attach_quota_seq.next_value, ?, ?)
BannerDAO.addNew = INSERT INTO jforum_banner (banner_id, banner_name, banner_placement, banner_description, banner_clicks, banner_views, banner_url, banner_weight, \
	banner_active, banner_comment, banner_type, banner_width, banner_height) VALUES (jforum_banner_seq.next_value, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
BanlistModel.insert = INSERT INTO jforum_banlist (banlist_id, user_id, banlist_ip, banlist_email) VALUES (jforum_banlist_seq.next_value, ?, ?, ?)

SearchModel.selectTopicData = INSERT INTO jforum_search_topics (topic_id, forum_id, topic_title, user_id, topic_time, \
	topic_views, topic_status, topic_replies, topic_vote_id, topic_type, topic_first_post_id, topic_last_post_id, moderated, session_id, search_time) \
	SELECT t.topic_id, t.forum_id, t.topic_title, t.user_id, t.topic_time, \
	t.topic_views, t.topic_status, t.topic_replies, t.topic_vote_id, t.topic_type, t.topic_first_post_id, t.topic_last_post_id, t.moderated, ?, sys_timestamp \
	FROM jforum_topics t, jforum_search_results s \
	WHERE t.topic_id = s.topic_id \
	AND s.session_id = ?

SearchModel.searchByTime = INSERT INTO jforum_search_results (topic_id, session_id, search_time) SELECT DISTINCT t.topic_id, ?, sys_timestamp FROM jforum_topics t, jforum_posts p \
	WHERE t.topic_id = p.topic_id \
	AND t.forum_id IN(:fids:) \
	AND p.post_time > ?

TopicModel.markAllAsUnread = UPDATE jforum_topics_watch SET is_read = 0 WHERE topic_id = ? AND user_id NOT IN (?, ?)

PostModel.selectById = SELECT p.post_id, topic_id, forum_id, p.user_id, post_time, poster_ip, enable_bbcode, enable_html, \
	enable_smilies, enable_sig, post_edit_time, post_edit_count, status, pt.post_subject, pt.post_text, username, p."attach", p.need_moderate \
	FROM jforum_posts p, jforum_posts_text pt, jforum_users u \
	WHERE p.post_id = pt.post_id \
	AND p.post_id = ? \
	AND p.user_id = u.user_id

TopicModel.selectById = SELECT t.*, p.user_id AS last_user_id, p.post_time, 0 AS "attach" \
	FROM jforum_topics t, jforum_posts p \
	WHERE t.topic_id = ? \
	AND p.post_id = t.topic_last_post_id

SearchModel.searchBase = SELECT t.*, p.user_id AS last_user_id, p.post_time, 0 AS "attach" \
	FROM jforum_search_topics t, jforum_posts p :table_category: \
	WHERE p.post_id = t.topic_last_post_id \
	AND t.session_id = ? \
	AND t.forum_id IN(:fids:) \
	:criterias: \
	ORDER BY :orderByField: :orderBy:

AttachmentModel.updatePost = UPDATE jforum_posts SET "attach" = ? WHERE post_id = ?

ModerationModel.topicsByForum = SELECT p.post_id, t.topic_id, t.topic_title, t.topic_replies, p.user_id, enable_bbcode, p."attach", \
	enable_html, enable_smilies, pt.post_subject, pt.post_text, username \
	FROM jforum_posts p, jforum_posts_text pt, jforum_users u, jforum_topics t \
	WHERE p.post_id = pt.post_id \
	AND p.topic_id = t.topic_id \
	AND t.forum_id = ? \
	AND p.user_id = u.user_id \
	AND p.need_moderate = 1 \
	ORDER BY t.topic_id, post_time ASC 


AttachmentModel.selectQuotaLimitByGroup = SELECT ql.quota_limit_id, ql.quota_desc, ql.quota_limit, ql.quota_type \
	FROM jforum_quota_limit ql, jforum_attach_quota atq \
	WHERE ql.quota_limit_id = atq.quota_limit_id \
	AND atq.group_id = ?

PrivateMessageModel.baseListing = SELECT jp.privmsgs_type, jp.privmsgs_id, jp.privmsgs_date, jp.privmsgs_subject, u.user_id, u.username \
	FROM jforum_privmsgs jp, jforum_users u \
	#FILTER# \
	ORDER BY jp.privmsgs_date DESC
	
PrivateMessageModel.inbox = WHERE privmsgs_to_userid = ? \
	AND u.user_id = jp.privmsgs_from_userid \
	AND ( jp.privmsgs_type = 1 \
	OR jp.privmsgs_type = 0 \
	OR privmsgs_type = 5)
	
PrivateMessageModel.sent = WHERE privmsgs_from_userid = ? \
	AND u.user_id = jp.privmsgs_to_userid \
	AND jp.privmsgs_type = 2
